"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[756],{22860:function(e,n,o){o.r(n),o.d(n,{AssetsGroupsGlobalGraphRoot:function(){return m}});var t=o(95764),i=o(30804),r=o(31112),s=o(12745),l=o(325),a=o(27601),c=o(13253),d=o(82348),u=o(77523),p=o(96294),x=o(78072),h=o(76336),f=o(77171),g=o(32289),j="__GLOBAL__",m=function(){var e=(0,a.UO)()[0],n=l.useContext(h.C5),o=n.allRepos,m=n.visibleRepos,C=(0,a.k6)();(0,d.j)("Global Asset Lineage");var b=l.useCallback((function(e,n){C[n]("/asset-groups".concat((0,p.gY)((0,t.Z)((0,t.Z)({},e),{},{pipelineName:j})).replace(j,"")))}),[C]),k=l.useCallback((function(e){C.push((0,f.p)(e.assetKey,{view:"definition"}))}),[C]),y=l.useMemo((function(){return{hideEdgesToNodesOutsideQuery:!1,hideNodesMatching:function(e){return!m.some((function(n){return n.repositoryLocation.name===e.repository.location.name&&n.repository.name===e.repository.name}))}}}),[m]);return(0,g.jsxs)(i.T,{style:{display:"flex",flexDirection:"column",paddingBottom:0},children:[(0,g.jsx)(r.m,{title:(0,g.jsx)(s.X6,{children:"Global Asset Lineage"}),right:(0,g.jsx)("div",{style:{marginBottom:-8},children:(0,g.jsx)(x.i,{label:"Reload definitions"})})}),(0,g.jsx)(c.OK,{fetchOptions:y,fetchOptionFilters:(0,g.jsx)(g.Fragment,{children:o.length>1&&(0,g.jsx)(u.C,{})}),options:{preferAssetRendering:!0,explodeComposites:!0},explorerPath:(0,p.p3)(j+e||"/"),onChangeExplorerPath:b,onNavigateToSourceAssetNode:k})]})};n.default=m},77523:function(e,n,o){o.d(n,{C:function(){return p}});var t=o(19065),i=o(8358),r=o(32030),s=o(75453),l=o(24971),a=o(325),c=o(93141),d=o(76336),u=o(32289),p=function(){var e=a.useContext(d.C5),n=e.allRepos,o=e.visibleRepos,p=e.toggleVisible,x=a.useState(!1),h=(0,t.Z)(x,2),f=h[0],g=h[1];return(0,u.jsxs)(u.Fragment,{children:[(0,u.jsxs)(i.Vq,{canOutsideClickClose:!0,canEscapeKeyClose:!0,isOpen:f,style:{width:"auto"},onClose:function(){return g(!1)},children:[(0,u.jsx)(i.fK,{icon:"repo",label:"Filter code locations"}),(0,u.jsx)(c.e,{options:n,onBrowse:function(){return g(!1)},onToggle:p,selected:o}),(0,u.jsx)(i.cN,{children:(0,u.jsx)(r.x,{padding:{top:8},children:(0,u.jsx)(s.zx,{intent:"none",onClick:function(){return g(!1)},children:"Done"})})})]}),(0,u.jsx)(s.zx,{intent:"none",icon:(0,u.jsx)(l.JO,{name:"folder"}),rightIcon:(0,u.jsx)(l.JO,{name:"expand_more"}),onClick:function(){return g(!0)},children:"".concat(o.length," of ").concat(n.length)})]})}},78072:function(e,n,o){o.d(n,{i:function(){return h}});var t=o(19065),i=o(11831),r=o(75453),s=o(24971),l=o(8358),a=o(325),c=o(63579),d=o(12436),u=o(17235),p=o(73362),x=o(32289),h=function(e){var n=e.label,o=void 0===n?"Reload all":n,h=(0,c.TE)().canReloadWorkspace,f=(0,u.Dc)({scope:"workspace",reloadFn:u.rL}),g=f.reloading,j=f.tryReload,m=f.error,C=f.errorLocationId,b=a.useState(!!m),k=(0,t.Z)(b,2),y=k[0],O=k[1];return a.useEffect((function(){return O(!!m)}),[m]),h.enabled?(0,x.jsxs)(x.Fragment,{children:[(0,x.jsx)(r.zx,{onClick:j,icon:(0,x.jsx)(s.JO,{name:"refresh"}),loading:g,intent:"none",children:o}),C?(0,x.jsx)(p.V,{error:m,location:C,reloading:g,onTryReload:j,onDismiss:function(){return O(!1)},isOpen:y}):(0,x.jsxs)(l.Vq,{icon:"error",title:"Reload error",canEscapeKeyClose:!1,canOutsideClickClose:!1,style:{width:"90%"},isOpen:y,children:[(0,x.jsx)(l.a7,{children:m&&(0,x.jsx)(d.T9,{error:m})}),(0,x.jsx)(l.cN,{children:(0,x.jsx)(r.zx,{onClick:function(){return O(!1)},children:"Dismiss"})})]})]}):(0,x.jsx)(i.u,{content:h.disabledReason,children:(0,x.jsx)(r.zx,{icon:(0,x.jsx)(s.JO,{name:"refresh"}),disabled:!0,intent:"none",children:o})})}}}]);
//# sourceMappingURL=756.98ac0fe5.chunk.js.map